@@ -39,12 +39,11 @@ pub enum FileFailurePersistence {
     /// `Direct("NUL")` on Windows (though it is internally handled by simply
     /// not doing any I/O).
     Off,
-    /// The path given to `TestRunner::set_source_file()` is parsed. The path
-    /// is traversed up the directory tree until a directory containing a file
-    /// named `lib.rs` or `main.rs` is found. A sibling to that directory with
-    /// the name given by the string in this configuration is created, and a
-    /// file with the same name and path relative to the source directory, but
-    /// with the extension changed to `.txt`, is used.
+    /// The path of the source file under test is traversed up the directory tree
+    /// until a directory containing a file named `lib.rs` or `main.rs` is found.
+    /// A sibling to that directory with the name given by the string in this
+    /// configuration is created, and a file with the same name and path relative
+    /// to the source directory, but with the extension changed to `.txt`, is used.
     ///
     /// For example, given a source path of
     /// `/home/jsmith/code/project/src/foo/bar.rs` and a configuration of
@@ -58,9 +57,9 @@ pub enum FileFailurePersistence {
     /// If no source file has been configured, a warning is printed and this
     /// behaves like `Off`.
     SourceParallel(&'static str),
-    /// The path given to `TestRunner::set_source_file()` is parsed. The
-    /// extension of the path is changed to the string given in this
-    /// configuration, and that filename is used.
+    /// Failures are persisted in a file with the same path as the source file
+    /// under test, but the extension is changed to the string given in this
+    /// configuration.
     ///
     /// For example, given a source path of
     /// `/home/jsmith/code/project/src/foo/bar.rs` and a configuration of
@@ -151,7 +150,7 @@ impl FailurePersistence for FileFailurePersistence {
                     path.display(),
                     e
                 );
-            } else if is_new {
+            } else {
                 eprintln!(
                     "proptest: Saving this and future failures in {}\n\
                      proptest: If this test was run on a CI system, you may \
@@ -403,15 +402,13 @@ impl FileFailurePersistence {
     }
 }
 
-lazy_static! {
-    /// Used to guard access to the persistence file(s) so that a single
-    /// process will not step on its own toes.
-    ///
-    /// We don't have much protecting us should two separate process try to
-    /// write to the same file at once (depending on how atomic append mode is
-    /// on the OS), but this should be extremely rare.
-    static ref PERSISTENCE_LOCK: RwLock<()> = RwLock::new(());
-}
+/// Used to guard access to the persistence file(s) so that a single
+/// process will not step on its own toes.
+///
+/// We don't have much protecting us should two separate process try to
+/// write to the same file at once (depending on how atomic append mode is
+/// on the OS), but this should be extremely rare.
+static PERSISTENCE_LOCK: RwLock<()> = RwLock::new(());
 
 #[cfg(test)]
 mod tests {
@@ -424,22 +421,20 @@ mod tests {
         misplaced_file: PathBuf,
     }
 
-    lazy_static! {
-        static ref TEST_PATHS: TestPaths = {
-            let crate_root = Path::new(env!("CARGO_MANIFEST_DIR"));
-            let lib_root = crate_root.join("src");
-            let src_subdir = lib_root.join("strategy");
-            let src_file = lib_root.join("foo.rs");
-            let subdir_file = src_subdir.join("foo.rs");
-            let misplaced_file = crate_root.join("foo.rs");
-            TestPaths {
-                crate_root,
-                src_file,
-                subdir_file,
-                misplaced_file,
-            }
-        };
-    }
+    static TEST_PATHS: std::sync::LazyLock<TestPaths> = std::sync::LazyLock::new(|| {
+        let crate_root = Path::new(env!("CARGO_MANIFEST_DIR"));
+        let lib_root = crate_root.join("src");
+        let src_subdir = lib_root.join("strategy");
+        let src_file = lib_root.join("foo.rs");
+        let subdir_file = src_subdir.join("foo.rs");
+        let misplaced_file = crate_root.join("foo.rs");
+        TestPaths {
+            crate_root,
+            src_file,
+            subdir_file,
+            misplaced_file,
+        }
+    });
 
     #[test]
     fn persistence_file_location_resolved_correctly() {
@@ -503,10 +498,7 @@ mod tests {
     #[test]
     fn relative_source_files_absolutified() {
         const TEST_RUNNER_PATH: &[&str] = &["src", "test_runner", "mod.rs"];
-        lazy_static! {
-            static ref TEST_RUNNER_RELATIVE: PathBuf =
-                TEST_RUNNER_PATH.iter().collect();
-        }
+        static TEST_RUNNER_RELATIVE: std::sync::LazyLock<PathBuf> = std::sync::LazyLock::new(|| TEST_RUNNER_PATH.iter().collect());
         const CARGO_DIR: &str = env!("CARGO_MANIFEST_DIR");
 
         let expected = ::std::iter::once(CARGO_DIR)
@@ -518,7 +510,7 @@ mod tests {
             &*expected,
             absolutize_source_file_with_cwd(
                 || Ok(Path::new(CARGO_DIR).to_owned()),
-                &TEST_RUNNER_RELATIVE
+                &*TEST_RUNNER_RELATIVE
             )
             .unwrap()
         );
@@ -528,7 +520,7 @@ mod tests {
             &*expected,
             absolutize_source_file_with_cwd(
                 || Ok(Path::new(CARGO_DIR).join("target")),
-                &TEST_RUNNER_RELATIVE
+                &*TEST_RUNNER_RELATIVE
             )
             .unwrap()
         );
